<?php

/**
 * Page callback which calls OAuth library to request and set the access
 * key and secret tokens.
 */
function qbo_api_oauth_page() {
  global $base_root;

  // Determine the context.
  if (!empty($_GET['context'])) {
    try {
      // Initialize QBO.
      $qbo = new QBO($_GET['context'], !empty($_GET['args']) ? $_GET['args'] : array());

      // Check access.
      if (!$qbo->context->access()) {
        // Deny access.
        drupal_access_denied();
      }
    }
    catch (QBOException $e) {
      drupal_access_denied();
    }
  }
  else {
    drupal_not_found();
  }

  // Extract the QBO keys.
  extract($qbo->keys);

  // We can't generate a token if the consumer keys aren't set.
  if (empty($consumer_key) || empty($consumer_secret)) {
    print t('OAuth consumer key and secret token must be set before requesting access tokens.');
    drupal_exit();
  }

  try {
    // Build the OAuth connection.
    $oauth = new OAuth($consumer_key, $consumer_secret, OAUTH_SIG_METHOD_HMACSHA1, OAUTH_AUTH_TYPE_URI);
    $oauth->enableDebug();

    // To avoid the error: (Peer certificate cannot be authenticated with given CA certificates).
    $oauth->disableSSLChecks();

    if (!isset($_GET['oauth_token']) && empty($access_token)) {
      // Get request token from QBO.
      $request_token = $oauth->getRequestToken(QBO_API_OAUTH_URL_REQUEST, $base_root . request_uri());

      // Store the token for later.
      $_SESSION['qbo_api_secret'] = $request_token['oauth_token_secret'];

      // Send user to QBO to authorize.
      header('Location: ' . QBO_API_OAUTH_URL_AUTHORISE . '?oauth_token=' . $request_token['oauth_token']);
    }

    if (isset($_GET['oauth_token']) && isset($_GET['oauth_verifier'])) {
      // Request an access token from QBO.
      $oauth->setToken($_GET['oauth_token'], $_SESSION['qbo_api_secret']);
      $access_token = $oauth->getAccessToken(QBO_API_OAUTH_URL_ACCESS);

      // Save the OAuth keys.
      $qbo->context->save(array(
        'access_token' => $access_token['oauth_token'],
        'access_secret' => $access_token['oauth_token_secret'],
        'auth_date' => REQUEST_TIME,
        'company_id' => $_REQUEST['realmId'],
      ));

      // Delete the token in the session.
      unset($_SESSION['qbo_api_secret']);

      // Use JS to refresh parent and close popup.
      echo '<script type="text/javascript">
              window.opener.location.href = window.opener.location.href;
              window.close();
            </script>';
    }
  }
  catch (OAuthException $e) {
    watchdog('qbo_api', $e->getMessage(), array(), WATCHDOG_ERROR);
    print t('An error occurred.');
    drupal_exit();
  }
}
